@@ -90,7 +90,9 @@ class backgrounds(TemplateFormat):
     def processingFile(self, textConfigFile, rootPath=None, nameFile=None):
         """Обработка конфигурационного файла"""
         if not (self.convert_cmd and self.identify_cmd):
-            self.setError(_("Format 'backgrounds' is unavailable"))
+            self.setError("%s. %s" % (_("Format 'backgrounds' is unavailable"),
+                                      _("Need to install {packages}").format(
+                                          packages="media-gfx/imagemagick")))
             return False
         if not self.source:
             self.setError(_("format=backgrounds need 'link' parameter"))
